@@ -1,9 +1,9 @@
 
 ## constructor
-EMM <- function(measure="euclidean", threshold=0.2, lambda=0, 
-	centroids=identical(tolower(measure), "euclidean")) {
+EMM <- function(threshold=0.2, measure="euclidean", 
+	centroids=identical(tolower(measure), "euclidean"), lambda=0) {
 
-	emm <- new("EMM", measure=measure, threshold=threshold, lambda=lambda,
+	new("EMM", measure=measure, threshold=threshold, lambda=lambda,
 		centroids=centroids, lambda_factor = 2^(-lambda))	
 }
 
